@@ -7,6 +7,8 @@
 #include <arc/UserConfig.h>
 
 #include "arcproxy-utils.h"
+#include "helpwindow.h"
+
 
 class ARCTools : public QObject
 {
@@ -14,6 +16,8 @@ class ARCTools : public QObject
 private:
     Arc::UserConfig* m_userConfig;
     ArcProxyController* m_proxyController;
+    QString m_jobListFile;
+    HelpWindow* m_helpWindow;
 public:
     static ARCTools* instance()
     {
@@ -44,6 +48,8 @@ public:
     Arc::UserConfig* currentUserConfig();
     bool hasValidProxy();
 
+    void setJobListFile(QString filename);
+    QString jobListFile();
 
     void proxyCertificateTool();
     void certConversionTool();
@@ -51,6 +57,9 @@ public:
     void submissionTool();
     void storageTool();
 
+    void showHelpWindow(QMainWindow* window);
+    void closeHelpWindow();
+
 private:
 
     ARCTools();
